==> grss-4.1.0-cp310-cp310-musllinux_1_2_x86_64.whl: grss/kernels/get_kernels.py <==
"""Download the custom and generic SPICE kernels from the
GRSS GitHub repository and the NAIF FTP server"""
import os
import time

# get the path to the directory containing this script
script_dir = os.path.dirname(os.path.realpath(__file__))

NAIF_SITE = 'https://naif.jpl.nasa.gov/pub/naif/generic_kernels'
SSD_SITE = 'https://ssd.jpl.nasa.gov/ftp'

# get the spice kernels if they are not already present
# de430 planets + de431 big16
mb430_exists = os.path.exists(f'{script_dir}/de430.bsp')
sb431_exists = os.path.exists(f'{script_dir}/sb431-n16s.bsp')
if (not mb430_exists or not sb431_exists):
    print('Downloading DE430/431 planet and big16 asteroid kernels...')
    os.system((f'curl --silent --show-error -o {script_dir}/de430.bsp '
                f'{NAIF_SITE}/spk/planets/de430.bsp'))
    os.system((f'curl --silent --show-error -o {script_dir}/sb431-n16s.bsp '
                f'{SSD_SITE}/xfr/sb431-n16s.bsp'))
# de440 planets + de441 big16
mb440_exists = os.path.exists(f'{script_dir}/de440.bsp')
sb441s_exists = os.path.exists(f'{script_dir}/sb441-n16s.bsp')
mb441_exists = os.path.exists(f'{script_dir}/de441_part-2.bsp')
sb441_exists = os.path.exists(f'{script_dir}/sb441-n16.bsp')
if (not mb440_exists or not mb441_exists or not sb441s_exists or not sb441_exists):
    print('Downloading DE440/441 planet and big16 asteroid kernels...')
    os.system((f'curl --silent --show-error -o {script_dir}/de440.bsp '
                f'{NAIF_SITE}/spk/planets/de440.bsp'))
    os.system((f'curl --silent --show-error -o {script_dir}/sb441-n16s.bsp '
                f'{SSD_SITE}/xfr/sb441-n16s.bsp'))
    os.system((f'curl --silent --show-error -o {script_dir}/de441_part-2.bsp '
                f'{NAIF_SITE}/spk/planets/de441_part-2.bsp'))
    os.system((f'curl --silent --show-error -o {script_dir}/sb441-n16.bsp '
                f'{SSD_SITE}/eph/small_bodies/asteroids_de441/sb441-n16.bsp'))

# get the earth orientation binary spice kernels and their comments if they are not already present
# latest earth pck
latest_earth_pck_exists = os.path.exists(f'{script_dir}/earth_latest_high_prec.bpc')
latest_earth_pck_old = (latest_earth_pck_exists and
                        time.time() - os.path.getmtime(f'{script_dir}/earth_latest_high_prec.bpc')
                        > 86400)
if not latest_earth_pck_exists or latest_earth_pck_old:
    print('Downloading latest Earth binary PCK...')
    os.system((f'curl --silent --show-error -o {script_dir}/earth_latest_high_prec.bpc '
                f'{NAIF_SITE}/pck/earth_latest_high_prec.bpc'))
# historical earth pck
historical_earth_pck_exists = os.path.exists(f'{script_dir}/earth_720101_230601.bpc')
if not historical_earth_pck_exists:
    print('Downloading historical Earth binary PCK...')
    os.system((f'curl --silent --show-error -o {script_dir}/earth_720101_230601.bpc '
                f'{NAIF_SITE}/pck/earth_720101_230601.bpc'))
# predicted earth pck
predicted_earth_pck_exists = os.path.exists(f'{script_dir}/earth_200101_990825_predict.bpc')
if not predicted_earth_pck_exists:
    print('Downloading predicted Earth binary PCK...')
    os.system((f'curl --silent --show-error -o {script_dir}/earth_200101_990825_predict.bpc '
                f'{NAIF_SITE}/pck/earth_200101_990825_predict.bpc'))
# generic frame kernels
generic_frame_kernel_exists = os.path.exists(f'{script_dir}/pck00011.tpc')
if not generic_frame_kernel_exists:
    print('Downloading generic frame kernel...')
    os.system((f'curl --silent --show-error -o {script_dir}/pck00011.tpc '
                f'{NAIF_SITE}/pck/pck00011.tpc'))

==> grss-4.1.3-cp310-cp310-musllinux_1_2_x86_64.whl: grss/kernels/get_kernels.py <==
"""Download the custom and generic SPICE kernels from the
GRSS GitHub repository and the NAIF FTP server"""
import os
import time

# get the path to the directory containing this script
script_dir = os.path.dirname(os.path.realpath(__file__))

NAIF_SITE = 'https://naif.jpl.nasa.gov/pub/naif/generic_kernels'
SSD_SITE = 'https://ssd.jpl.nasa.gov/ftp'

# get the spice kernels if they are not already present
# de430 planets + de431 big16
mb430_exists = os.path.exists(f'{script_dir}/de430.bsp')
sb431_exists = os.path.exists(f'{script_dir}/sb431-n16s.bsp')
if (not mb430_exists or not sb431_exists):
    print('Downloading DE430/431 planet and big16 asteroid kernels...')
    os.system((f'curl --silent --show-error -o {script_dir}/de430.bsp '
                f'{NAIF_SITE}/spk/planets/de430.bsp'))
    os.system((f'curl --silent --show-error -o {script_dir}/sb431-n16s.bsp '
                f'{SSD_SITE}/xfr/sb431-n16s.bsp'))
# de440 planets + de441 big16
mb440_exists = os.path.exists(f'{script_dir}/de440.bsp')
sb441s_exists = os.path.exists(f'{script_dir}/sb441-n16s.bsp')
mb441_exists = os.path.exists(f'{script_dir}/de441.bsp')
sb441_exists = os.path.exists(f'{script_dir}/sb441-n16.bsp')
if (not mb440_exists or not mb441_exists or not sb441s_exists or not sb441_exists):
    print('Downloading DE440/441 planet and big16 asteroid kernels...')
    os.system((f'curl --silent --show-error -o {script_dir}/de440.bsp '
                f'{SSD_SITE}/eph/planets/bsp/de440.bsp'))
    os.system((f'curl --silent --show-error -o {script_dir}/sb441-n16s.bsp '
                f'{SSD_SITE}/xfr/sb441-n16s.bsp'))
    os.system((f'curl --silent --show-error -o {script_dir}/de441.bsp '
                f'{SSD_SITE}/eph/planets/bsp/de441.bsp'))
    os.system((f'curl --silent --show-error -o {script_dir}/sb441-n16.bsp '
                f'{SSD_SITE}/eph/small_bodies/asteroids_de441/sb441-n16.bsp'))

# get the earth orientation binary spice kernels and their comments if they are not already present
# latest earth pck
latest_earth_pck_exists = os.path.exists(f'{script_dir}/earth_latest_high_prec.bpc')
latest_earth_pck_old = (latest_earth_pck_exists and
                        time.time() - os.path.getmtime(f'{script_dir}/earth_latest_high_prec.bpc')
                        > 86400)
if not latest_earth_pck_exists or latest_earth_pck_old:
    print('Downloading latest Earth binary PCK...')
    os.system((f'curl --silent --show-error -o {script_dir}/earth_latest_high_prec.bpc '
                f'{NAIF_SITE}/pck/earth_latest_high_prec.bpc'))
# historical earth pck
historical_earth_pck_exists = os.path.exists(f'{script_dir}/earth_720101_230601.bpc')
if not historical_earth_pck_exists:
    print('Downloading historical Earth binary PCK...')
    os.system((f'curl --silent --show-error -o {script_dir}/earth_720101_230601.bpc '
                f'{NAIF_SITE}/pck/earth_720101_230601.bpc'))
# predicted earth pck
predicted_earth_pck_exists = os.path.exists(f'{script_dir}/earth_200101_990825_predict.bpc')
if not predicted_earth_pck_exists:
    print('Downloading predicted Earth binary PCK...')
    os.system((f'curl --silent --show-error -o {script_dir}/earth_200101_990825_predict.bpc '
                f'{NAIF_SITE}/pck/earth_200101_990825_predict.bpc'))
# generic frame kernels
generic_frame_kernel_exists = os.path.exists(f'{script_dir}/pck00011.tpc')
if not generic_frame_kernel_exists:
    print('Downloading generic frame kernel...')
    os.system((f'curl --silent --show-error -o {script_dir}/pck00011.tpc '
                f'{NAIF_SITE}/pck/pck00011.tpc'))
